==> ulyxex.0.1.1.with-tinyMce.zip: pages/admin_link_modify.php <==
<?php
if (!isset($admin)) exit("admin val");
if ($_SESSION['level'] > 2)  exit("user level");
require("code/admin_link_modify.php");
require("code/action_links.php");
/****************************************/
/* page elements						*/
$o_link = new LinkModify();
/****************************************/
/* page vars							*/
/* check post 							*/
$LinkId = isset($_GET['link'])?$h->num($_GET['link']):$h->num($_POST['link']);
/****************************************/
/* page elements						*/
$userdat = $o_link->user_params($_SESSION['userid']);
if ($_SESSION['level'] > 1) {
/* check if user own the link level 3*/
	$linkDat = $o_link->link_params($LinkId);
	if ($linkDat['USERID'] != $userdat['ID']) exit("you can't modify this link");
}
$css = $h->css("css/".ADMINCSS,1);
$meta = $h->meta("Content-Type","text/html; charset=UTF-8");
$title = $h->title($tr->ws("modify link of").$userdat['USERNAME']);
$head = $h->head($meta.$css.$title);
$topPage = $h->h1($tr->ws("modify link of").$h->span($userdat['USERNAME'],"class='username'"));
$topPage .= $h->h2($actionsLinks[$_SESSION['level']]);

$bottomPage = $h->uCredits(0,1);

/****************************************/
/* page data							*/	
$data = "";
if (isset($_POST['update'])) $data .= $o_link->update_link($LinkId);
$data .= $o_link->data_link($LinkId);

/****************************************/
/* show									*/
$bottomPage .= $h->countQ();
$body = $h->body($topPage.$data.$bottomPage);
$page = $h->html5($head.$body);

echo $page;
?>

==> ulyxex.0.1.2.with-tinyMce.zip: pages/admin_link_modify.php <==
<?php
if (!isset($admin)) exit("not in admin !");
if ($_SESSION['level'] > 2)  exit("bad user level !");
require("code/admin_link_modify.php");
require("code/action_links.php");
/****************************************/
/* page elements						*/
$o_link = new LinkModify();
/****************************************/
/* page vars							*/
/* check post 							*/
$LinkId = isset($_GET['link'])?$h->num($_GET['link']):$h->num($_POST['link']);
/****************************************/
/* page elements						*/
$userdat = $o_link->user_params($_SESSION['userid']);
if ($_SESSION['level'] > 1) {
/* check if user own the link level 3*/
	$linkDat = $o_link->link_params($LinkId);
	if ($linkDat['USERID'] != $userdat['ID']) exit("you can't modify this link !");
}
$css = $h->css("css/".ADMINCSS,1);
$meta = $h->meta("Content-Type","text/html; charset=UTF-8");
$title = $h->title($tr->ws("modify link of").$userdat['USERNAME']);
$head = $h->head($meta.$css.$title);
$topPage = $h->h1($tr->ws("modify link of").$h->span($userdat['USERNAME'],"class='username'"));
$topPage .= $h->h2($actionsLinks[$_SESSION['level']]);

$bottomPage = $h->uCredits(0,1);

/****************************************/
/* page data							*/	
$data = "";
if (isset($_POST['update'])) $data .= $o_link->update_link($LinkId);
$data .= $o_link->data_link($LinkId);

/****************************************/
/* show									*/
$bottomPage .= $h->countQ();
$body = $h->body($topPage.$data.$bottomPage);
$page = $h->html5($head.$body);

echo $page;
?>
